************************
Cloud Inquisitor Backend
************************

Please check out the `documentation <https://cloud-inquisitor.readthedocs.io>`_ for the full details on how
``Cloud Inquisitor`` backend is built and what technologies we use.
